#activity-stream .activity-portrait img {
    position: absolute;
	top:0px;
	left:0px;
    clip: rect(0px 48px 48px 0px);
	
}
#activity-stream .activity-portrait {
    float: left;
    height: 48px !important;
	width: 48px !important;
    margin: 0.3em 0.5em 0 0 !important;
    padding: 0px;
    position: relative;
}
#activity-stream .comment-portrait img {
    position: absolute;
	top:0px;
	left:0px;
    clip: rect(0px 32px 32px 0px);
}
#activity-stream .comment-portrait {
    float: left;
    height: 34px !important;
	width: 32px !important;
    margin: 2px 4px 2px 2px !important;
    padding: 0px;
    position: relative;
}

#activity-stream .activity-wrapper {
	float:left;
	width:88%;
}

#activity-stream ul.activities {
	margin-left: 0;
	margin-right: 0;
}
#activity-stream ul.activities li {
	/*border-bottom: 1px solid #e0e0e0;*/
	list-style: none;
	padding: 0.5em 0 0 0;
		width:100%;
}

#activity-stream .small-personal-portrait {
	width:48px;
}
#activity-stream .very-small-personal-portrait {
	width:32px;
}


#activity-stream ul.comments {
	margin: 0 0 0 0; 
	padding: 0; 
		list-style:none;
}

#activity-stream ul.comments li.comment {
	float:left;
		width:98%;		
	margin:4px 0 4px 0;
	padding:2px;
	font-size:11px;
		overflow:hidden;
                background-color: #F6F6F6;
                border: 1px solid #CCCCCC;		
				border-radius:0.3em;
}

.activity-frame {
	position:absolute;
                background-color: #F6F6F6;
                border: 1px solid #CCCCCC;      
                border-radius:0.3em;
				height:80px;
}

#activity-stream .comment-input-field textarea {	
	border:1px solid #ccc;
	margin:0;
	padding:2px;
	width:98%;
}

.activity-all-button {
	float: right;
	margin:0 0 0 0;
	font-size:10px;
	color:#205C90;
	cursor:pointer;		
}

button.css3button {
    font-family: Arial, Helvetica, sans-serif;
    font-size: 14px;
    color: #d4d4d4;
    padding: 10px 20px;
    background: -moz-linear-gradient(
        top,
        #303030 0%,
        #1a1a1a);
    background: -webkit-gradient(
        linear, left top, left bottom, 
        from(#303030),
        to(#1a1a1a));
    border-radius: 4px;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    border: 1px solid #575757;
    -moz-box-shadow:
        0px 1px 1px rgba(000,000,000,0.5),
        inset 0px 0px 1px rgba(255,255,255,0.7);
    -webkit-box-shadow:
        0px 1px 1px rgba(000,000,000,0.5),
        inset 0px 0px 1px rgba(255,255,255,0.7);
    text-shadow:
        0px -1px 0px rgba(0,0,0,0.4),
        0px 1px 0px rgba(255,255,255,0.3);
}

.test-button,
.activity-all-button,
.activity-more-button,
#activity-stream .comment-input-button,
#activity-stream .comment-save-button,
#activity-stream .comment-all-button {
	cursor:pointer;	
}
.activity-all-button {
	float:right;
}

#activity-stream .activity-more-button {
	margin:0;
	float:none;	
	text-align:center;
}


#activity-stream .activity-hide-button,
#activity-stream .comment-hide-button {
	background:  transparent url("++resource++ityou.astream.images/eye-close.png") no-repeat center right ;
	padding:2px 6px 2px 6px;
	font-size:10px;
	color:#FFF;
	cursor:pointer;		
	float:right;	
	   height:12px;
	   width:17px
}



#activity-stream pre {
	background-color:transparent;
	color:#333;
    font-family: "lucida grande",tahoma,verdana,arial,sans-serif;
	font-size:11px;	
	line-height:1.3em;	
	margin:0;
	padding:0;
}

#activity-stream .comment-wrapper {
	margin-left:37px;
}

#activity-stream .comment-input-field {
	display:none;
}
#activity-stream .comment-input-field textarea {
    
}
.comment-all-button {
	/*background:none;*/
	   display:none;
}
.hash {
	display:none;
}

.jq-render {
	
}
.jq-render-ex {
	
}

#activity-stream .visualClear {
	font-size:1!important;
	height:1px !important;
	margin:0;
	padding:0;
}

.activity-controls {
	padding:0.5em 0 0.5em 0;
}

.activity-controls button.btn {
    margin-right: 0;
}

.activity-controls [class*="col-"] {
    padding-right: 0;
    padding-left: 0;
}

.activities-footer {
	text-align:center;
	margin:1em 0;
}
 

.activity-text a,
.comment-wrapper a {
    font-weight: bold;
}

.activity-text .user-name {}

.activity-text .user-message,
.comment-wrapper .user-message {
    color:#454545 !important;
}

.comment-wrapper .c-timestamp,  
.activity-text .timestamp {
    font-style:italic;
}

#activity_choice {
	list-style: none;
	padding: 0;
	margin: 0;
	cursor: pointer;
}

#activity_choice li {
	float: left;
	border: 1px solid #bbb;
	border-radius: 3px;
	border-bottom-width: 0;
	margin: 0;
	list-style: none;
}

#activity_choice a {
	text-decoration: none;
	display: block;
	background: #EAEAEA;
	padding: 0.24em 1em;
	color: #454545;
	width: 14em;
	text-align: center;
}

#activity_choice a:hover {
	background: #F6F6F6;
}

#activity_choice .selected {
	border-color: #454545;
}

#activity_choice .selected a {
	position: relative;
	top: 1px;
	background: #F6F6F6;
	color: #454545;
	font-weight: bold;
}

#activity_send {
	float: right;
}

#user-activity-form {
	height: 1.5em;
}

#user-activity-form.active {
	height: 3em;
}

#plone-contentmenu-factories a,
#content-views a
{
	display: none !important;
}

.ajax-params.invisible {display:none}


#astream-tabs {
    margin: 10px 0;
}

#astream-tabs li {
    display: inline;
}

#astream-tabs ul {
    margin: 0;
}

#astream-tabs .pagination > li > a {
    padding-left: 5px;
    padding-right: 5px;
}

/*#astream-tabs ul {
    list-style: none outside none;
    margin: 0;
    padding: 0;
}
#astream-tabs li {
    -moz-border-bottom-colors: none;
    -moz-border-left-colors: none;
    -moz-border-right-colors: none;
    -moz-border-top-colors: none;
    border-color: #CCCCCC;
    border-image: none;
    border-style: solid;
    border-width: 1px 1px 0;
    float: left;
    margin: 0;
    width: auto;
   	padding: 0.24em 1em;
}

#astream-tabs .astream-tab-all {
    border-radius: 4px 0 0 0;	
}
#astream-tabs .astream-tab-following {
    border-radius: 0 4px 0 0;
    background: none repeat scroll 0 0 #EEEEEE;
    color: #0000CC;
    display: block;
    text-align: center;
    text-decoration: none;
}

#astream-tabs li:hover {
    background: none repeat scroll 0 0 #EEEDDD;
    cursor: pointer;
}
#astream-tabs .selected {
    border-color: #CCCCCC;
    background: none repeat scroll 0 0 white;
    color: black;
    font-weight: bold;
    position: relative;
}*/

.user-message.icons-on .contenttype-document, .user-message.icons-on .contenttype-event, .user-message.icons-on .contenttype-folder,
.user-message.icons-on .contenttype-link, .user-message.icons-on .contenttype-news-item, .user-message.icons-on .contenttype-plone-site,
.user-message.icons-on .contenttype-topic, .user-message.icons-on #plone-contentmenu-factories .contenttype-file,
.user-message.icons-on #plone-contentmenu-factories .contenttype-image {
	padding-left: 16px !important;	
}

.user-message .file-icon {
	padding-right: 1px;
}

#content .thumbnail a.link-overlay {
	border-bottom: none !important;
}

.activity-wrapper .thumbnail {
	display: none;
}

.activity-wrapper .thumbnail.hover {
	display: block;
	position: absolute;
	background: none repeat scroll 0 0 rgba(250, 250, 250, 0.95) !important;
	border: 1px solid #CCCCCC;
	border-radius: 4px 4px 4px 4px;
	box-shadow: 0 0 12px rgba(100, 100, 100, 0.6);
	height: auto;
	padding: 10px;
	z-index: 2;
}

#astream-tabs .astream-tab-following.inactive {
	color: #DDDDDD;
}
